@@ -9,6 +9,9 @@
 
 import IMP.algebra
 import IMP.statistics
+import sys
+
+IMP.setup_from_argv(sys.argv, "kmeans")
 
 # generate some clusters of points
 vs = []
@@ -26,6 +29,6 @@ c = IMP.statistics.create_lloyds_kmeans(e,
                                         3, 1000)
 
 # print out the cluster results
-print c.get_cluster_center(0)
-print c.get_cluster_center(1)
-print c.get_cluster_center(2)
+print(c.get_cluster_center(0))
+print(c.get_cluster_center(1))
+print(c.get_cluster_center(2))
